@@ -17,9 +17,9 @@ double quantile(double * x, int n, double q, int copy, int * err);
 
 void testMedian(double *x, int * n, double * res);
 
-void prepareColBicor(double * col, int nr, double maxPOutliers, int fallback, double * res, 
+void prepareColBicor(double * col, int nr, double maxPOutliers, int fallback, int cosine, double * res, 
                      int * nNAentries, int * NAmed, int *zeroMAD, double * aux, double * aux2);
 
-void prepareColCor(double * x, int nr, double * res, int * nNAentries, int * NAmean);
+void prepareColCor(double * x, int nr, int cosine, double * res, int * nNAentries, int * NAmean);
 
 #endif
